@@ -84,7 +84,9 @@ sub get_extended_sysinfo
                 $info->{'type'} ne 'link'            &&
                 $info->{'module'} ne 'mailbox'       &&
                 $info->{'module'} ne 'system-status' &&
-                $info->{'type'} ne 'warning')
+                $info->{'type'} ne 'warning'         &&
+                $a->{'type'} ne 'warning'            &&
+                $b->{'type'} ne 'warning')
             {
                 our $charts_not_supported = 'no';
                 if ($info->{'type'} eq 'chart') {
@@ -479,8 +481,8 @@ sub print_sysstats_panel_start
     my %virtualmin_config = foreign_config('virtual-server');
     my %cloudmin_config   = foreign_config('server-manager');
 
-    print '<div id="system-status" class="panel panel-default dashboard" style="margin-bottom: 5px">' . "\n";
-    print '<div class="panel-heading">'."\n";
+    print '<div id="system-status" class="panel panel-default" style="margin-bottom: 5px">' . "\n";
+    print '<div class="panel-heading">' . "\n";
     my $debug_mode = theme_debug_mode() ? '&nbsp;&nbsp;<i class="fa2 fa2-bug fa-0_75x opacity-0_2"></i>' : "";
     print '<h3 class="panel-title">'
       .
@@ -759,7 +761,14 @@ sub get_sysinfo_vars
                         $vs_license eq '0' ? ' GPL&nbsp;&nbsp;' :
                         ''
 
-                        . ' Professional <div class="btn-group margined-left-4' . $is_hidden_link . '">' ) .
+                        . ' Professional <div class="btn-group margined-left-4' . $is_hidden_link . '">'
+                        .
+                        ( ($vs_license eq '1') ?
+                            ' <a data-license class="btn btn-default btn-xxs" data-container="body" title="' .
+                            $theme_text{'right_vlcheck'} . '" href=\'' .
+                            $theme_webprefix . '/virtual-server/licence.cgi\'><i class="fa fa-refresh"></i></a></div>' :
+                            '</div>')
+                    ) .
                     ($vs_license eq '1' ? '' : '&nbsp;') .
                     '<a class="btn btn-default btn-xxs margined-left--1" data-container="body" title="' .
                     $theme_text{'theme_xhred_sysinfo_vmforum'} .
@@ -1264,7 +1273,7 @@ sub print_favorites
               <li class="menu-exclude exclude favorites-title">
                 <h1><i class="fa fa-star-o"></i>&nbsp;&nbsp;'
       . $theme_text{'left_favorites'} .
-'<sup style="position: absolute; margin: 33px 0 0 -10px;" class="hidden">&nbsp;&nbsp;<small class="text-white"> <a aria-label="'
+'<sup style="position: absolute; margin: 25px 0 0 -10px;" class="hidden">&nbsp;&nbsp;<small class="text-white"> <a aria-label="'
       . $theme_text{'theme_xhred_filemanager_context_edit'}
       . '" href="' .
       $theme_webprefix . '/settings-editor_' . (foreign_available('webmin') ? undef : 'favorites_') . 'read.cgi?file=' .
