@@ -18,12 +18,10 @@ return $get_ps_version_cache;
 sub list_processes
 {
 local($pcmd, $line, $i, %pidmap, @plist, $dummy, @w, $_);
-local @want = grep { /^\d+$/ } @_;
-return ( ) if (@_ && !@want);
 local $ver = &get_ps_version();
 if ($ver && $ver < 2) {
 	# Old version of ps
-	$pcmd = join(' ' , @want);
+	$pcmd = join(' ' , @_);
 	open(PS, "ps aulxhwwww $pcmd 2>/dev/nul |");
 	for($i=0; $line=<PS>; $i++) {
 		chop($line);
@@ -84,7 +82,7 @@ else {
 			# Skip process ID 0 or ps command
 			$i--; next;
 			}
-		if (@want && &indexof($w[4], @want) < 0) {
+		if (@_ && &indexof($w[4], @_) < 0) {
 			# Not interested in this PID
 			$i--; next;
 			}
@@ -130,8 +128,7 @@ return @plist;
 sub renice_proc
 {
 return undef if (&is_readonly_mode());
-local $out = &backquote_logged("renice ".quotemeta($_[1])." -p ".
-			       quotemeta($_[0])." 2>&1");
+local $out = &backquote_logged("renice $_[1] -p $_[0] 2>&1");
 if ($?) { return $out; }
 return undef;
 }
@@ -161,51 +158,6 @@ $out =~ s/^\s+//g; $out =~ s/\s+$//g;
 return split(/\s+/, $out);
 }
 
-# linux_openpty()
-# Linux-only, pure-Perl openpty(3)-style helper.
-# Returns master fh, slave fh, slave path, and ioctl value on success
-sub linux_openpty
-{
-
-require Fcntl; Fcntl->import(qw(O_RDWR));
-require POSIX; POSIX->import(qw(setsid));
-
-# Linux ioctl values
-my $TIOCGPTN   = 0x80045430;	# get pty number
-my $TIOCSPTLCK = 0x40045431;	# unlock slave
-my $TIOCSCTTY  = 0x540E;	# set controlling tty
-
-my ($ptmx, $ttyfh);
-
-# Open PTY master
-sysopen($ptmx, "/dev/ptmx", O_RDWR) || return;
-
-# Unlock the slave
-my $lock = pack("i", 0);
-ioctl($ptmx, $TIOCSPTLCK, $lock) || do {
-	close($ptmx);
-	return;
-	};
-
-# Get slave number
-my $buf = pack("i", 0);
-ioctl($ptmx, $TIOCGPTN, $buf) || do {
-	close($ptmx);
-	return;
-	};
-my $n = unpack("i", $buf);
-
-# Open PTY slave
-my $tty = "/dev/pts/$n";
-open($ttyfh, "+<", $tty) || do {
-	close($ptmx);
-	return;
-	};
-
-# Return master fh, slave fh, slave path, ioctl value
-return ($ptmx, $ttyfh, $tty, $TIOCSCTTY);
-}
-
 # get_new_pty()
 # Returns the filehandles and names for a pty and tty
 sub get_new_pty
@@ -405,10 +357,9 @@ sub open_process_trace
 local $fh = time().$$;
 local $sc;
 if (@{$_[1]}) {
-	$sc = "-e trace=".join(",", map { quotemeta($_) } grep { $_ ne "" }
-				 @{$_[1]});
+	$sc = "-e trace=".join(",", @{$_[1]});
 	}
-local $tpid = open($fh, "strace -t -p ".quotemeta($_[0])." $sc 2>&1 |");
+local $tpid = open($fh, "strace -t -p $_[0] $sc 2>&1 |");
 $line = <$fh>;
 return { 'pid' => $_[0],
 	 'tpid' => $tpid,
